Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(712)

Unified Diff: runtime/lib/error.dart

Issue 10977078: Rename CastException to CastError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Now without the TODO. Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/core/errors.dart ('k') | runtime/vm/exceptions.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/lib/error.dart
diff --git a/runtime/lib/error.dart b/runtime/lib/error.dart
index 973252757800495b602b0c13428e0b6d5672582a..925b99c0b516553d9b78ab9c77fa051c59a95e90 100644
--- a/runtime/lib/error.dart
+++ b/runtime/lib/error.dart
@@ -50,15 +50,15 @@ class TypeErrorImplementation
final String malformedError;
}
-class CastExceptionImplementation
+class CastErrorImplementation
extends TypeErrorImplementation
- implements CastException {
- factory CastException._uninstantiable() {
+ implements CastError {
+ factory CastError._uninstantiable() {
throw const UnsupportedOperationException(
- "CastException can only be allocated by the VM");
+ "CastError can only be allocated by the VM");
}
// A CastException is allocated by TypeError._throwNew() when dst_name equals
// Exceptions::kCastExceptionDstName.
String toString() {
String str = (malformedError != null) ? malformedError : "";
if ((dstName != null) && (dstName.length > 0)) {
@@ -50,15 +50,15 @@ class TypeErrorImplementation
}
- // A CastException is allocated by TypeError._throwNew() when dst_name equals
- // Exceptions::kCastExceptionDstName.
+ // A CastError is allocated by TypeError._throwNew() when dst_name equals
+ // Exceptions::kCastErrorDstName.
String toString() {
String str = (malformedError != null) ? malformedError : "";
« no previous file with comments | « lib/core/errors.dart ('k') | runtime/vm/exceptions.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698